@@ -11,11 +11,12 @@ def transcribe_prepare_node(region, account_id, cytoscape_node_data):
             print('Found a cloudtrail transcribe file')
             cytoscape_node_data.append({
                 "data": {
-                    "type": "transcribe",
+                    "type": "Transcribe",
                     "id": "transcribe",
                     "region": region,
                     "account_id": account_id,
                     "name": "transcribe",
+                    "cost_for_month": "24.04 USD"
                 }
             })
             break
